@@ -20,7 +20,7 @@ class DiscordPDA(discord.AutoShardedClient):
         log.debug(f"Creating new DiscordPDA...")
 
         log.debug(f"Subscribing to guild_messages and dm_messages by setting intents...")
-        intents = discord.Intents(guild_messages=True, dm_messages=True)
+        intents = discord.Intents(guilds=True, guild_messages=True, dm_messages=True)
 
         log.debug(f"Initializing AutoShardedClient...")
         super().__init__(*args, intents=intents, **kwargs)
